@@ -8,8 +8,11 @@ ciAgrestiCoull <- function(event, n, level = 0.95) {
   n <- n + z^2
   p <- 1 / n * (event + 0.5 * z^2)
   
-  lower  <- p - z * sqrt(1 / n * p * (1 - p))
-  upper  <- p + z * sqrt(1 / n * p * (1 - p))
+  lower <- p - z * sqrt(1 / n * p * (1 - p))
+  upper <- p + z * sqrt(1 / n * p * (1 - p))
+  ##
+  lower[lower < 0] <- 0
+  upper[upper > 1] <- 1
   
   list(n = n, p = p, lower = lower, upper = upper, level = level)
 }
